library(car)
library(dplyr)
library(ggplot2)
library(lmne)
library(lme4)

cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

setwd("~/Research/populations/Cadenza")

# experimental design
# three isogenic accessions (Canthatch, NS1, and NS2) were grown in three different greenhouse during the Spring/Summer of 2018
# six replicates were grown per 


agronomy = read.table(file="Canthatch_agronomy_2018.txt", header=T)
agronomy = data.frame(agronomy)
ggplot(agronomy, aes(Location, weight)) + geom_jitter(width=0.1) + ylim(0,3.5) + ggtitle("Location x Hundred grain weight")
ggplot(agronomy, aes(Genotype, weight)) + geom_jitter(width=0.1) + ylim(0,3.5) + ggtitle("Genotype x Hundred grain weight")
ggplot(agronomy, aes(Genotype, weight)) + geom_jitter(width=0.1) + ylim(0,3.5) + ggtitle("Genotype x Hundred grain weight") + facet_grid(. ~ Location)

awn.mlm = lme(awn ~ Genotype, random = ~ 1|Location, data = agronomy)
FL.mlm = lme(FL ~ Genotype, random = ~ 1|Location, data = agronomy)
emergence1in.mlm = lme(emergence1in ~ Genotype, random = ~ 1|Location, data = agronomy)
numseed.mlm = lme(numseed ~ Genotype, random = ~ 1|Location, data = agronomy)

summary(awn.mlm)
summary(FL.mlm)
summary(emergence1in.mlm)
summary(numseed.mlm)

weight.lm = lm(weight ~ Genotype, data = agronomy)

res = aov(weight ~ Genotype * Location, data=agronomy)
Anova(res, type="III")

# balanced data, removal of cases of seven genotypes versus six
bagronomy = read.table(file="Canthatch_agronomy_2018_balanced.txt", header=T)


## FL analysis
ggplot(agronomy, aes(Genotype, FL)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)

### ANOVA
res.aov3 = aov(FL ~ Genotype * Location, data = bagronomy)
summary(res.aov3)

### output means and sd
group_by(bagronomy, Genotype, Location) %>% summarise(count = n(), mean(FL, na.rm=TRUE), sd=sd(FL, na.rm=TRUE))

### pairwise test significance
TukeyHSD(res.aov3, which="Genotype")

### Homogeneity of variance
plot(res.aov3, 1)
leveneTest(FL ~ Genotype, data = bagronomy)

### Normality
plot(res.aov3, 2)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)

### Non-parametric tests
kruskal.test(FL ~ Genotype, data = bagronomy)
pairwise.wilcox.test(bagronomy$FL, bagronomy$Genotype, p.adjust.method = "BH")


## awn analysis
ggplot(agronomy, aes(Genotype, awn)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)

### ANOVA
res.aov3 = aov(awn ~ Genotype * Location, data = bagronomy)
summary(res.aov3)

### output means and sd
group_by(bagronomy, Genotype, Location) %>% summarise(count = n(), mean(awn, na.rm=TRUE), sd=sd(awn, na.rm=TRUE))

### pairwise test significance
TukeyHSD(res.aov3, which="Genotype")

### Homogeneity of variance
plot(res.aov3, 1)
leveneTest(awn ~ Genotype, data = bagronomy)

### Normality
plot(res.aov3, 2)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)

### Non-parametric tests
kruskal.test(awn ~ Genotype, data = bagronomy)
pairwise.wilcox.test(bagronomy$awn, bagronomy$Genotype, p.adjust.method = "BH")


## emergence of spike (1/4) analysis
ggplot(agronomy, aes(Genotype, emergence1in)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)

### ANOVA
res.aov3 = aov(emergence1in ~ Genotype * Location, data = bagronomy)
summary(res.aov3)

### output means and sd
group_by(bagronomy, Genotype, Location) %>% summarise(count = n(), mean(emergence1in, na.rm=TRUE), sd=sd(emergence1in, na.rm=TRUE))

### pairwise test significance
TukeyHSD(res.aov3, which="Genotype")

### Homogeneity of variance
plot(res.aov3, 1)
leveneTest(emergence1in ~ Genotype, data = bagronomy)

### Normality
plot(res.aov3, 2)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)

### Non-parametric tests
kruskal.test(emergence1in ~ Genotype, data = bagronomy)
pairwise.wilcox.test(bagronomy$emergence1in, bagronomy$Genotype, p.adjust.method = "BH")


## numseed analysis
ggplot(agronomy, aes(Genotype, numseed)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)

### ANOVA
res.aov3 = aov(numseed ~ Genotype * Location, data = bagronomy)
summary(res.aov3)

### output means and sd
group_by(bagronomy, Genotype, Location) %>% summarise(count = n(), mean(numseed, na.rm=TRUE), sd=sd(numseed, na.rm=TRUE))

### pairwise test significance
TukeyHSD(res.aov3, which="Genotype")

### Homogeneity of variance
plot(res.aov3, 1)
leveneTest(numseed ~ Genotype, data = bagronomy)

### Normality
plot(res.aov3, 2)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)

### Non-parametric tests
kruskal.test(numseed ~ Genotype, data = bagronomy)
pairwise.wilcox.test(bagronomy$numseed, bagronomy$Genotype, p.adjust.method = "BH")


## weight analysis
### ANOVA
res.aov3 = aov(weight ~ Genotype * Location, data = bagronomy)
summary(res.aov3)

### output means and sd
group_by(bagronomy, Genotype, Location) %>% summarise(count = n(), mean(weight, na.rm=TRUE), sd=sd(weight, na.rm=TRUE))

### pairwise test significance
TukeyHSD(res.aov3, which="Genotype")

### Homogeneity of variance
plot(res.aov3, 1)
leveneTest(weight ~ Genotype, data = bagronomy)

### Normality
plot(res.aov3, 2)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)

### Non-parametric tests
kruskal.test(weight ~ Genotype, data = bagronomy)
pairwise.wilcox.test(bagronomy$weight, bagronomy$Genotype, p.adjust.method = "BH")








# FL, normally distributed
res.aov3 = aov(FL ~ Genotype * Location, data = bagronomy)
aov_residuals = residuals(object = res.aov3)
shapiro.test(x = aov_residuals)


weight = read.table(file="Canthatch_agronomy_2018_techrep_weight.txt", header=T)
weight = data.frame(weight)

postscript(file="Canthatch_agronomy_2018_awn_emergence.ps", width=3, height=2)
ggplot(bagronomy, aes(Genotype, awn)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)
dev.off()

postscript(file="Canthatch_agronomy_2018_flowering_time.ps", width=3, height=2)
ggplot(bagronomy, aes(Genotype, FL)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)
dev.off()

postscript(file="Canthatch_agronomy_2018_emergence.ps", width=3, height=2)
ggplot(bagronomy, aes(Genotype, emergence1in)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)
dev.off()

postscript(file="Canthatch_agronomy_2018_weight100.ps", width=3, height=2)
ggplot(bagronomy, aes(Genotype, weight)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)
dev.off()

postscript(file="Canthatch_agronomy_2018_numseed.ps", width=3, height=2)
ggplot(bagronomy, aes(Genotype, numseed)) + geom_boxplot(width=0.2, outlier.size=0.5) + geom_jitter(aes(x=as.numeric(Genotype)+0.3, color=Location), width=0.1, size=0.5) + scale_colour_manual(values=cbbPalette)
dev.off()

weight.lm = lm(weight ~ Genotype, data = weight)
summary(weight.lm)

weight$mainplot = weight$Genotype
weight.mlm = lme(weight ~ Genotype, random = ~ 1|Location, data = weight)
summary(weight.mlm)


# example data set
# experimental design
# The yield of oats from a split-plot field trial using three varieties and four levels of manurial treatment. The experiment was laid out in 6 blocks of 3 main plots, each split into 4 sub-plots. The varieties were applied to the main plots and the manurial treatments to the sub-plots.

library(MASS)
data(oats)

names(oats) = c('block', 'variety', 'nitrogen', 'yield')
oats$mainplot = oats$variety
oats$subplot = oats$nitrogen
summary(oats)

ggplot(oats, aes(variety, yield)) + geom_boxplot() + geom_point() + geom_jitter(width=0.1)

library(nlme)
m1.nlme = lme(yield ~ variety*nitrogen, random = ~ 1|block/mainplot, data = oats)
summary(m1.nlme)


library(lme4)
library(lmerTest)
library(pbkrtest)

m1.lme4 = lmer(yield ~ variety + nitrogen + variety*nitrogen + (1|block/mainplot), data = oats)
summary(m1.lme4)
anova(m1.lme4)
anova(m1.lme4, ddf="Kenward-Roger")
